
## Table of Contents

### Getting started

- [Installing](installing.md)
- [Installing on non-x86](installing_on_non_x86.md)
- [GDB setup](gdb_setup.md)

### User documentation

- [Terminology](terminology.md)
- [Target support](target_support.md)
- [Debug probes](debug_probes.md)
- [Configuration](configuration.md)
- [User scripts](user_scripts.md)
- [Remote probe access](remote_probe_access.md)
- [Configuring logging](configuring_logging.md)
- [Target security features](security.md)
- [Debugging multicore devices](multicore_debug.md)
- [Semihosting](semihosting.md)
- [SWO/SWV](swo_swv.md)
- [Target family usage notes](target_notes.md)

### Reference

- [Built-in targets](builtin-targets.md)
- [Session options reference](options.md)
- [Command reference](command_reference.md)
- [Environment variables](env_vars.md)

### Python API

- [Introduction to the pyOCD Python API](python_api.md)
- [Python API examples](api_examples.md)

### Developer documentation

- [Developers’ guide](developers_guide.md)
- [How to add new targets](adding_new_targets.md)
- [Running the automated tests](automated_tests.md)
- Internal design
  - [Architecture overview](architecture.md)
  - [Remote probe protocol](remote_probe_protocol.md)




